SystemOrganization addCategory: #ConfigurationOfPolySource!

Object subclass: #ConfigurationOfPolySource
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPolySource'!

!ConfigurationOfPolySource class methodsFor: 'development support' stamp: 'DaleHenrichs 12/17/2010 10:23'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfPolySource class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 16:51'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfPolySource class methodsFor: 'private' stamp: 'DaleHenrichs 12/6/2010 13:34'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfPolySource class methodsFor: 'private' stamp: 'DaleHenrichs 11/4/2010 10:23'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfPolySource class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 11/2/2010 14:58'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPolySource class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPolySource class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfPolySource class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfPolySource class methodsFor: 'accessing' stamp: 'dkh 10/13/2009 10:36'!
project

	^self new project! !

!ConfigurationOfPolySource class methodsFor: 'development support' stamp: 'DaleHenrichs 1/13/2011 15:37'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfPolySource methodsFor: 'baselines' stamp: 'TM 2/28/2011 10:55:04.777'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate' username: Utilities authorInitials password: ''.

		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'SqSync' with: [
			spec
				className: 'ConfigurationOfSqSync';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'ProcessSpecific' with: [
			spec repository: 'http://www.squeaksource.com/ProcessLocalStorage'].

		spec
			package: 'MethodWrappers';
			package: 'PolySource' with: [spec requires: #('SqSync' 'MethodWrappers' 'Signals' 'ProcessSpecific' 'Animations' 'Widgets')].
		spec
			group: 'default' with: #('PolySource')].! !

!ConfigurationOfPolySource methodsFor: 'baselines' stamp: 'TM 2/27/2011 22:45:41.518'!
baseline200: spec 
	<version: '2.0-baseline'>

	spec for: #common do: [
      	spec blessing: #baseline.
		
		"setting of private repository"
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate' username: Utilities authorInitials password: ''.

		spec package: 'ProcessSpecific' with: [
			spec repository: 'http://www.squeaksource.com/ProcessLocalStorage'].

		spec
			package: 'PolySource' with: [spec requires: #('ProcessSpecific')].
			
		spec
			group: 'default' with: #('PolySource')].! !

!ConfigurationOfPolySource methodsFor: 'accessing' stamp: 'DaleHenrichs 11/5/2010 13:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfPolySource methodsFor: 'symbolic versions' stamp: 'TM 2/27/2011 21:42:06.025'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.1.x' version: '2.0'.
	spec for: #'squeak4.2.x' version: '2.0'.
! !

!ConfigurationOfPolySource methodsFor: 'versions' stamp: 'mt 2/5/2011 17:42:10.58'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		
		spec package: 'PolySource' with: 'PolySource-mt.89'].! !

!ConfigurationOfPolySource methodsFor: 'versions' stamp: 'TM 2/28/2011 08:59:08.323'!
version200: spec

	<version: '2.0' imports: #('2.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		
		spec package: 'PolySource' with: 'PolySource-bs.98'].! !
